#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Transaction based daemon and clients for package management tasks."""
# Copyright (C) 2008-2009 Sebastian Heinlein <devel@glatzor.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

__author__ = "Sebastian Heinlein <devel@glatzor.de>"
__state__ = "development"
__version__ = '1.1.1'

__all__ = ("client", "console", "core", "debconf", "defer", "enums",
           "errors", "gtkwidgets", "loop", "policykit1", "progress",
           "test", "utils", "worker")

# vim:ts=4:sw=4:et
